select.dropdown {
  padding: 4px;
  font-size: 18px;
  border: solid 1px lightgray;
  border-radius: 2px;
  outline: none;
}
.select_interpretation > div {
  font-weight: bold;
  padding: 4px;
  font-size: 12px;
  box-sizing: border-box;
}